R/alphabeta_window.R
alphabeta_window.Rdcompute alpha and beta diversity metrics from pixel data corresponding to spectral species extracted from a window
alphabeta_window(
SSwindow,
nb_clusters,
Beta_info,
alpha_metrics,
beta_metrics,
pcelim = 0.02,
Hill_order = 1,
diss_output = FALSE,
p = NULL
)dataframe. spectral species corresponding to a raster subset (window = elementary spatial unit of process)
numeric. number of clusters used in kmeans
list. BC dissimilarity & associated beta metrics
list. alpha diversity metrics
list. beta diversity metrics
numeric. min proportion of pixels to consider spectral species
numeric. Hill order
boolean set TRUE to get dissimilarity matrices as outputs
list. progressor object for progress bar
list of alpha and beta diversity metrics corresponding to SSwindow