This function performs big raster processing It requires user to write a function expecting vectors / matrices / dataframes corresponding to raster data read sequentially, a list of input files, a list of output files, and it is good to go.

apply_bigRaster(
  funct,
  input_rasters,
  input_args = NULL,
  output_rasters,
  output_lyrs = NULL,
  filetype = "EHdr",
  bandNames = NULL,
  unit_nrows = NULL,
  maxRows = NULL
)

Arguments

funct

function. function to be applied to process chunks of big rasters

input_rasters

list. path for input files to be processed

input_args

list. additional arguments sent to funct

output_rasters

list. path for output file to be written

output_lyrs

numeric. number of bands for output raster

filetype

character. name of GDAL driver

bandNames

list. list of band names corresponding to output files

unit_nrows

numeric. define to read a number of lines multiple of unit_nrows

maxRows

numeric. maximumnumber of rows to process at once

Value

output_rasters list. path for output files