R/biodivMapR_opt_clusters.R
biodivMapR_opt_clusters.Rdapply biodivMapR on a test set for different numbers of clusters
biodivMapR_opt_clusters(
input_raster_path,
input_vector_path,
obs2optimize,
selected_bands,
obs_criterion = "shannon",
input_mask_path = NULL,
output_dir = "./",
nb_clusters = 50,
min_sun = 0.25,
nb_iter = 10,
pcelim = 0.02,
nb_repetitions = 50,
nb_samples_alpha = 1e+05,
nb_samples_beta = 1000,
Hill_order = 1,
algorithm = "Hartigan-Wong",
nbCPU = 1,
overwrite = TRUE
)SpatRaster or list of SpatRaster
SpatVector or SpatVectorCollection
numeric .list of ground obs diversity metrics corresponding to input_vector. Expected values: richness, shannon, simpson, bray
numeric. bnds to select from input_raster
character. richness, shannon, simpson or bray
SpatRaster corresponding to mask
character. output directory
numeric.
numeric.
numeric.
numeric.
numeric.
numeric.
numeric.
numeric.
character.
numeric.
boolean
list including performances (pearson and spearman correlation) with nb_clusters