These functions are provided for compatibility with older versions of biodivMapR but are deprecated.

biodivMapR_full(
  input_raster_path,
  input_mask_path = NULL,
  output_dir,
  window_size,
  selected_bands = NULL,
  Kmeans_info_save = NULL,
  Kmeans_info_read = NULL,
  Beta_info_save = NULL,
  Beta_info_read = NULL,
  nbCPU = 1,
  options = NULL
)

biodivMapR_full_tiles(
  feature_dir,
  list_features,
  mask_dir = NULL,
  output_dir,
  window_size,
  plots,
  nbCPU = 1,
  site_name = NULL,
  options = NULL
)

Arguments

input_raster_path

See the new functions that replace the old ones

input_mask_path

See the new functions that replace the old ones

output_dir

See the new functions that replace the old ones

window_size

See the new functions that replace the old ones

selected_bands

See the new functions that replace the old ones

Kmeans_info_save

See the new functions that replace the old ones

Kmeans_info_read

See the new functions that replace the old ones

Beta_info_save

See the new functions that replace the old ones

Beta_info_read

See the new functions that replace the old ones

nbCPU

See the new functions that replace the old ones

options

See the new functions that replace the old ones

feature_dir

See the new functions that replace the old ones

list_features

See the new functions that replace the old ones

mask_dir

See the new functions that replace the old ones

plots

See the new functions that replace the old ones

site_name

See the new functions that replace the old ones