minmax: this function performs rescaling and either defines min and...

Description Usage Arguments Value

View source: R/Lib_PerformPCA.R

Description

this function performs rescaling and either defines min and max from each feature in a data set, or applies the transformation based on a previously defined min and max

Usage

1
minmax(x, mode = "define", MinX = FALSE, MaxX = FALSE)

Arguments

x

numeric. data matrix

mode

character. 'define' or 'apply'

MinX

numeric. if 'apply'

MaxX

numeric. if 'apply'

Value

rescaled data, min and max values


floriandeboissieu/biodivMapR documentation built on March 11, 2021, 8:46 a.m.