write_raster: Writes a matrix or an array into a ENVI BIL raster

Description Usage Arguments Value

View source: R/Lib_ImageProcess.R

Description

Writes a matrix or an array into a ENVI BIL raster

Usage

1
2
3
4
5
6
7
8
9
write_raster(
  Image,
  HDR,
  ImagePath,
  window_size,
  FullRes = TRUE,
  LowRes = FALSE,
  SmoothImage = FALSE
)

Arguments

Image

numeric. matrix or array of image to be written

HDR

hdr template

ImagePath

path of image file to be written

window_size

spatial units use dto compute diversiy (in pixels)

FullRes

should full resolution image be written (original pixel size)

LowRes

should low resolution image be written (one value per spatial unit)

SmoothImage

boolean. set TRUE if you want smooting filter applied to resulting diversity rasters

Value

None


floriandeboissieu/biodivMapR documentation built on March 11, 2021, 8:46 a.m.