R/apply_bigRaster.R
apply_bigRaster.RdThis function performs big raster processing It requires user to write a function expecting vectors / matrices / dataframes corresponding to raster data read sequentially, a list of input files, a list of output files, and it is good to go.
apply_bigRaster(
funct,
input_rasters,
input_args = NULL,
output_rasters,
output_lyrs = NULL,
filetype = "EHdr",
bandNames = NULL,
unit_nrows = NULL,
maxRows = NULL
)function. function to be applied to process chunks of big rasters
list. path for input files to be processed
list. additional arguments sent to funct
list. path for output file to be written
numeric. number of bands for output raster
character. name of GDAL driver
list. list of band names corresponding to output files
numeric. define to read a number of lines multiple of unit_nrows
numeric. maximumnumber of rows to process at once
output_rasters list. path for output files