These functions are provided for compatibility with older versions of biodivMapR but are deprecated.
biodivMapR_full(
input_raster_path,
input_mask_path = NULL,
output_dir,
window_size,
selected_bands = NULL,
Kmeans_info_save = NULL,
Kmeans_info_read = NULL,
Beta_info_save = NULL,
Beta_info_read = NULL,
nbCPU = 1,
options = NULL
)
biodivMapR_full_tiles(
feature_dir,
list_features,
mask_dir = NULL,
output_dir,
window_size,
plots,
nbCPU = 1,
site_name = NULL,
options = NULL
)See the new functions that replace the old ones
See the new functions that replace the old ones
See the new functions that replace the old ones
See the new functions that replace the old ones
See the new functions that replace the old ones
See the new functions that replace the old ones
See the new functions that replace the old ones
See the new functions that replace the old ones
See the new functions that replace the old ones
See the new functions that replace the old ones
See the new functions that replace the old ones
See the new functions that replace the old ones
See the new functions that replace the old ones
See the new functions that replace the old ones
See the new functions that replace the old ones
See the new functions that replace the old ones