Description Usage Arguments Value
View source: R/Lib_PerformPCA.R
this function performs rescaling and either defines min and max from each feature in a data set, or applies the transformation based on a previously defined min and max
1 |
x |
numeric. data matrix |
mode |
character. 'define' or 'apply' |
MinX |
numeric. if 'apply' |
MaxX |
numeric. if 'apply' |
rescaled data, min and max values
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.